#include "game.h"

typedef enum GameState {
	WAIT_TO_START,
	PLAYING
} GameState;

static char* p_backgroundFilepath = "background.imag";

Sprite* p_pressToPlay;
static char* p_pressToPlayFilepath = "start.cel";

GameState p_state = WAIT_TO_START;

void p_showPressToStartSprite() {
	sprite_moveTo( p_pressToPlay, display_getScreenWidth() - 222, display_getScreenHeight() - 136 );
}

void game_init() {
	display_loadBackground( p_backgroundFilepath );
	
	p_pressToPlay = sprite_load( p_pressToPlayFilepath );
	display_displayListAdd( 
		(Node*)p_pressToPlay, 
		TRUE, 
		sprite_allocateNextIndex()
		);
	p_showPressToStartSprite();
	
	bullets_init();
	attacker_init( invaders_checkCollision );
	invaders_init( attacker_checkCollision );
	gauge_init();
}

void p_restartGame() {
	bullets_loadDefaults();
	invaders_loadDefaults();
	attacker_loadDefaults();
	gauge_loadDefaults();
}

void p_state_waitToStart() {
	// cause some randomness
	rand();
	
	if( input_isTapped( BUTTON_C ) ) {
		sprite_hide( p_pressToPlay );
		p_restartGame();
		p_state = PLAYING;
	}
}

void p_state_playing() {
	int attackerLife = attacker_getLife();
	
	if( attackerLife == 0 || invaders_countRemaining() == 0 ) {
		p_showPressToStartSprite();
		p_state = WAIT_TO_START;
	}
	
	gauge_setValue( attackerLife );
	
	invaders_refresh();
	attacker_refresh();
	
	if( input_isTapped( BUTTON_B ) ) {
		invaders_forceCursorMove();
	}
	if( input_isTapped( BUTTON_A ) ) {
		invaders_fire();
	}
	
	bullets_refresh();
	gauge_refresh();
}

void game_mainLoop() {
	
	input_read();
	
	switch( p_state ) {
		case WAIT_TO_START:
			p_state_waitToStart();
			break;
		case PLAYING:
			p_state_playing();
			break;
	}
	
	display_render();
}

