#include "gauge.h"
#include "math.h"

#define BUBBLE_SPRITE_SIZE 8
#define BUBBLE_PADDING 2
#define SCREEN_PADDING 15
#define NUM_BUBBLES 10

static char* p_bubblesFilepath = "bubble.cel";
static char* p_enemyLifeFilepath = "enemylife.cel";

Sprite* p_bubbles[NUM_BUBBLES];
Sprite* p_enemyLife;
int p_current;

int p_getXByIndex( int index ) {
	return SCREEN_PADDING + ( BUBBLE_SPRITE_SIZE + BUBBLE_PADDING ) * index;
}

int p_getY() {
	return display_getScreenHeight() - SCREEN_PADDING - BUBBLE_SPRITE_SIZE;
}

void gauge_setValue( int current ) {
	p_current = MIN( current, NUM_BUBBLES );
}

void gauge_loadDefaults() {
	p_current = 0;
}

void gauge_refresh() {
	int i;
	
	// show all
	for( i = 0; i < NUM_BUBBLES; i++ ) {
		sprite_moveTo( p_bubbles[i], p_getXByIndex( i ), p_getY() );
	}
	
	// hide from end as necessary
	for( i = NUM_BUBBLES - 1; i >= 0 ; i-- ) {
		if( i < p_current ) {
			return;
		}
		
		sprite_hide( p_bubbles[i] );
	}
}

void gauge_init() {
	int i;
	
	p_enemyLife = sprite_load( p_enemyLifeFilepath );
	display_displayListAdd( 
		(Node*)p_enemyLife, 
		TRUE, 
		sprite_allocateNextIndex()
		);
	sprite_moveTo( p_enemyLife, SCREEN_PADDING, display_getScreenHeight() - SCREEN_PADDING - 35 );
	
	for( i = 0; i < NUM_BUBBLES; i++ ) {
		p_bubbles[i] = sprite_load( p_bubblesFilepath );
		sprite_hide( p_bubbles[i] );
		
		display_displayListAdd( 
			(Node*)p_bubbles[i], 
			TRUE, 
			sprite_allocateNextIndex()
			);
	}
	
	gauge_loadDefaults();
}
