#include "sprites.h"

#define	SPRITES_DIRECTORY "Sprites/"

int32 p_nextSpriteIndex = 1;

CCB* p_setCommonCCB( ANIM* spriteData ) {
	
	int32 index;
	CCB* ccb = spriteData->pentries[0].af_CCB;
	
	// copy first CCB into each pentry
	for( index = 0; index < spriteData->num_Frames; index++ ) {
		spriteData->pentries[index].af_CCB = ccb;
	}

	return ccb;
}

Sprite* sprite_load( char *filename ) {
	
	Sprite* sprite = (Sprite*)AllocMem( sizeof( Sprite ), MEMTYPE_ANY );
	
	// build file path
	char basePath[ MAX_PATH ] = SPRITES_DIRECTORY;
	strcat( basePath, filename );
	
	// load
	sprite->data = LoadAnim( basePath, MEMTYPE_CEL );
	
	sprite->ccb = p_setCommonCCB( sprite->data );
	
	sprite->width = sprite->ccb->ccb_Width;
	sprite->height = sprite->ccb->ccb_Height;
	
	sprite_setFrame( sprite, 0 );
	
	return sprite;
}

void sprite_moveTo( Sprite *sprite, int32 x, int32 y ) {
	sprite->position.topLeft.pt_X = x;
	sprite->position.topLeft.pt_Y = y;
	sprite->position.bottomRight.pt_X = x + sprite->width - 1;
	sprite->position.bottomRight.pt_Y = y + sprite->height - 1;
}

void sprite_setFrame( Sprite *sprite, int32 frame ) {
	sprite->animationFrame = frame;
}

int32 sprite_allocateNextIndex() {
	return p_nextSpriteIndex++;
}

bool sprite_isRectangleOverlap( Rectangle* first, Rectangle* second ) {
	bool atLeastOneDimensionDoesntOverlap = 
		first->bottomRight.pt_X < second->topLeft.pt_X ||
		second->bottomRight.pt_X < first->topLeft.pt_X ||
		first->bottomRight.pt_Y < second->topLeft.pt_Y || 
		second->bottomRight.pt_Y < first->topLeft.pt_Y;
		
	return !atLeastOneDimensionDoesntOverlap;
}

void sprite_hide( Sprite* sprite ) {
	sprite_moveTo( sprite, display_getScreenWidth(), 0 );
}